@@ -56,7 +56,7 @@ extern SEXP R_git_repository_clone(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEX
 extern SEXP R_git_repository_find(SEXP);
 extern SEXP R_git_repository_info(SEXP);
 extern SEXP R_git_repository_init(SEXP, SEXP);
-extern SEXP R_git_repository_ls(SEXP);
+extern SEXP R_git_repository_ls(SEXP, SEXP);
 extern SEXP R_git_repository_open(SEXP, SEXP);
 extern SEXP R_git_repository_path(SEXP);
 extern SEXP R_git_repository_rm(SEXP, SEXP);
@@ -69,7 +69,7 @@ extern SEXP R_git_stash_list(SEXP);
 extern SEXP R_git_stash_pop(SEXP, SEXP);
 extern SEXP R_git_stash_save(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP R_git_stat_files(SEXP, SEXP, SEXP);
-extern SEXP R_git_status_list(SEXP, SEXP);
+extern SEXP R_git_status_list(SEXP, SEXP, SEXP);
 extern SEXP R_git_submodule_info(SEXP, SEXP);
 extern SEXP R_git_submodule_init(SEXP, SEXP, SEXP);
 extern SEXP R_git_submodule_list(SEXP);
@@ -128,7 +128,7 @@ static const R_CallMethodDef CallEntries[] = {
   {"R_git_repository_find",     (DL_FUNC) &R_git_repository_find,     1},
   {"R_git_repository_info",     (DL_FUNC) &R_git_repository_info,     1},
   {"R_git_repository_init",     (DL_FUNC) &R_git_repository_init,     2},
-  {"R_git_repository_ls",       (DL_FUNC) &R_git_repository_ls,       1},
+  {"R_git_repository_ls",       (DL_FUNC) &R_git_repository_ls,       2},
   {"R_git_repository_open",     (DL_FUNC) &R_git_repository_open,     2},
   {"R_git_repository_path",     (DL_FUNC) &R_git_repository_path,     1},
   {"R_git_repository_rm",       (DL_FUNC) &R_git_repository_rm,       2},
@@ -141,7 +141,7 @@ static const R_CallMethodDef CallEntries[] = {
   {"R_git_stash_pop",           (DL_FUNC) &R_git_stash_pop,           2},
   {"R_git_stash_save",          (DL_FUNC) &R_git_stash_save,          5},
   {"R_git_stat_files",          (DL_FUNC) &R_git_stat_files,          3},
-  {"R_git_status_list",         (DL_FUNC) &R_git_status_list,         2},
+  {"R_git_status_list",         (DL_FUNC) &R_git_status_list,         3},
   {"R_git_submodule_info",      (DL_FUNC) &R_git_submodule_info,      2},
   {"R_git_submodule_init",      (DL_FUNC) &R_git_submodule_init,      3},
   {"R_git_submodule_list",      (DL_FUNC) &R_git_submodule_list,      1},
